==> nextcloud-29.0.14.tar.bz2: nextcloud/apps/text/l10n/id.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Berkas terunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Berkas terunggah melampau parameter upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The file was only partially uploaded" : "Berkas hanya sebagian terunggah",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Could not write file to disk" : "Tidak dapat menulis berkas ke diska",
    "A PHP extension stopped the file upload" : "Ekstensi PHP menghentikan proses unggah berkas",
    "No file uploaded or file size exceeds maximum of %s" : "Gagal unggah berkas atau ukuran melampaui batas maksimum %s",
    "New text file" : "Berkas teks baru",
    "File not found" : "Berkas tidak ditemukan",
    "Text" : "Teks",
    "Translate" : "Terjemahkan",
    "Reload" : "Muat ulang",
    "Edit guest name" : "Edit nama tamu",
    "Guest" : "Tamu",
    "Save guest name" : "Simpan nama tamu",
    "guest" : "pengunjung",
    "Saving …" : "Menyimpan ...",
    "Saved" : "Disimpan",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Link" : "Tautan",
    "Undo" : "Undo",
    "Cancel" : "Batal",
    "URL" : "URL",
    "Formatting help" : "Bantuan pemformatan",
    "Select file or folder to link to" : "Pilih berkas atau folder untuk ditautkan",
    "to" : "untuk",
    "Replace" : "Timpa",
    "Edit" : "Sunting",
    "Source code" : "Kode sumber",
    "Both" : "Keduanya",
    "Done" : "Selesai",
    "Lists" : "Daftar",
    "Details" : "Detail",
    "Formatting" : "Pemformatan",
    "Info" : "Info",
    "Success" : "Berhasil",
    "Warning" : "Peringatan",
    "Control" : "Kendali",
    "Add notes, lists or links …" : "Tambahkan catatan, daftar, atau tautan..."
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.11rc1.tar.bz2: nextcloud/apps/text/l10n/id.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Berkas terunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Berkas terunggah melampau parameter upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The file was only partially uploaded" : "Berkas hanya sebagian terunggah",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Could not write file to disk" : "Tidak dapat menulis berkas ke diska",
    "A PHP extension stopped the file upload" : "Ekstensi PHP menghentikan proses unggah berkas",
    "No file uploaded or file size exceeds maximum of %s" : "Gagal unggah berkas atau ukuran melampaui batas maksimum %s",
    "New text file" : "Berkas teks baru",
    "File not found" : "Berkas tidak ditemukan",
    "Text" : "Teks",
    "Reload" : "Muat ulang",
    "Guest" : "Tamu",
    "you" : "Anda",
    "edit" : "ubah",
    "Copy link" : "Salin tautan",
    "guest" : "pengunjung",
    "Saving …" : "Menyimpan ...",
    "Saved" : "Disimpan",
    "Unsaved changes" : "Perubahan belum disimpan",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Link" : "Tautan",
    "Undo" : "Undo",
    "Redo" : "Ulang lagi",
    "Cancel" : "Batal",
    "URL" : "URL",
    "Formatting help" : "Bantuan pemformatan",
    "Translate" : "Terjemahkan",
    "Delete task" : "Hapus tugas",
    "to" : "untuk",
    "Replace" : "Timpa",
    "Upload" : "Unggah",
    "Edit" : "Sunting",
    "Source code" : "Kode sumber",
    "Both" : "Keduanya",
    "Done" : "Selesai",
    "Lists" : "Daftar",
    "Details" : "Detail",
    "Formatting" : "Pemformatan",
    "Select file or folder to link to" : "Pilih berkas atau folder untuk ditautkan",
    "Choose" : "Pilih",
    "Add folder description" : "Tambahkan deskripsi folder",
    "Edit guest name" : "Edit nama tamu",
    "Save guest name" : "Simpan nama tamu"
},
"nplurals=1; plural=0;");
